//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Device/Mask/DetectorMask.h
//! @brief     Defines class DetectorMask.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_DEVICE_MASK_DETECTORMASK_H
#define BORNAGAIN_DEVICE_MASK_DETECTORMASK_H

#include "Device/Data/Powerfield.h"
#ifndef SWIG
#include "Base/Types/OwningVector.h"
#endif

class Histogram2D;
class IAxis;
class IShape2D;

template <class T>
class Powerfield;

//! Collection of detector masks.
//! @ingroup detector

class DetectorMask {
public:
    DetectorMask();
    ~DetectorMask();
    DetectorMask(const DetectorMask& other);
    DetectorMask& operator=(const DetectorMask& other);

    //! Add mask to the stack of detector masks.
    //! The value "true" means that the area will be excluded from the analysis.
    //! @param shape The shape of mask.
    //! @param mask_value The value of mask
    void addMask(const IShape2D& shape, bool mask_value);

    //! Init the map of masks for the given detector plane
    void initMaskData(const IAxis& xAxis, const IAxis& yAxis);

    bool isMasked(size_t index) const;

    const Powerfield<bool>* getMaskData() const { return &m_mask_data; }

    Histogram2D* createHistogram() const;

    //! Returns true if has masks
    bool hasMasks() const;

    int numberOfMaskedChannels() const { return m_number_of_masked_channels; }

    size_t numberOfMasks() const;

    const IShape2D* getMaskShape(size_t mask_index, bool& mask_value) const;

private:
    void process_masks();

#ifndef SWIG
    OwningVector<IShape2D> m_shapes;
#endif
    std::vector<bool> m_mask_of_shape;
    Powerfield<bool> m_mask_data;
    int m_number_of_masked_channels;
};

#endif // BORNAGAIN_DEVICE_MASK_DETECTORMASK_H
