#!/usr/bin/env python3
"""
An example of computing reflectivity on a
magnetized sample.
"""

import bornagain as ba
from bornagain import angstrom, ba_plot as bp, deg, nm, R3

import matplotlib.pyplot as plt


def get_sample():
    """
    Defines sample and returns it
    """

    # Define materials
    material_Ambient = ba.MaterialBySLD("Ambient", 0, 0)
    magnetic_field = R3(0, 1e8, 0)
    material_Layer = ba.MaterialBySLD("Layer", 0.0001, 1e-08,
                                      magnetic_field)
    material_Substrate = ba.MaterialBySLD("Substrate", 7e-05, 2e-06)

    # Define layers
    layer_1 = ba.Layer(material_Ambient)
    layer_2 = ba.Layer(material_Layer, 10*nm)
    layer_3 = ba.Layer(material_Substrate)

    # Define sample
    sample = ba.MultiLayer()
    sample.addLayer(layer_1)
    sample.addLayer(layer_2)
    sample.addLayer(layer_3)

    return sample


def get_simulation(sample, scan_size=500):
    """
    Defines and returns a specular simulation.
    """


def simulate(polarizer_dir, analyzer_dir, title):
    n = bp.simargs['n']
    simulation = ba.SpecularSimulation()
    scan = ba.AlphaScan(1.54*angstrom, n, 0, 5*deg)
    simulation.setScan(scan)
    simulation.setSample(get_sample())

    simulation.instrument().setPolFilters(polarizer_dir, analyzer_dir, 1,
                                          0.5)

    result = simulation.simulate()
    result.setTitle(title)
    return result


def run_simulations():
    return ret


if __name__ == '__main__':
    bp.parse_args(sim_n=500)

    results = [
        simulate(ba.R3(0, +1, 0), ba.R3(0, +1, 0), "$++$"),
        simulate(ba.R3(0, -1, 0), ba.R3(0, -1, 0), "$--$"),
    ]

    bp.plot_multicurve_specular(results)
