//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/CatDevice/InstrumentItemCatalog.h
//! @brief     Defines class InstrumentItemCatalog
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_CATDEVICE_INSTRUMENTITEMCATALOG_H
#define BORNAGAIN_GUI_MODEL_CATDEVICE_INSTRUMENTITEMCATALOG_H

#include <QString>
#include <QVector>

class InstrumentItem;

class InstrumentItemCatalog {
public:
    using CatalogedType = InstrumentItem;

    // Do not change the numbering! It is serialized!
    enum class Type : uint8_t { GISAS = 0, OffSpec = 1, Specular = 2, DepthProbe = 3 };

    struct UiInfo {
        QString menuEntry;
        QString description;
    };

    //! Creates the item of the given type.
    static InstrumentItem* create(Type type);

    //! Available types of items.
    static QVector<Type> types();

    //! UiInfo on the given type.
    static UiInfo uiInfo(Type t);

    //! Returns the enum type of the given item.
    static Type type(const InstrumentItem* item);
};

#endif // BORNAGAIN_GUI_MODEL_CATDEVICE_INSTRUMENTITEMCATALOG_H
