//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Data/DataProperties.h
//! @brief     Defines class DataProperties and its descendants
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_DATA_DATAPROPERTIES_H
#define BORNAGAIN_GUI_MODEL_DATA_DATAPROPERTIES_H

#include "GUI/Model/BaseItem/SessionItem.h"
#include "3rdparty/GUI/qcustomplot/qcustomplot.h"

class DataItem;

//! Implements a link to DataItem. If path name
//! of a DataItem changes, the link becomes invalid.
//! Also serves as a base for Data1DProperties
class BA_CORE_API_ DataProperties : public SessionItem {
private:
    static constexpr auto P_DATALINK{"data link"};

public:
    void setDataItem(DataItem* item);
    DataItem* dataItem();

protected:
    DataProperties(const QString& model_type);
};

//! Holds data required for 1D DataItem representation
class Data1DProperties : public DataProperties {
private:
    static constexpr auto P_COLOR{"Color"};
    static constexpr auto P_SCATTER{"Scatter"};
    static constexpr auto P_LINE{"Line"};

public:
    static constexpr auto M_TYPE{"DataItem1DProperties"};

    Data1DProperties();

    //! Creates and returns a color object from color name
    QColor color();

    //! Returns the name of the color
    QString colorName() const;

    //! Returns set up color ComboProperty.
    void setColorProperty(const QString& color_name);

    //! Returns a QCP scatter object from its name
    QCPScatterStyle::ScatterShape scatter();

    //! Returns a QCP line object from its name
    QCPGraph::LineStyle line();

    //! Set up scatter for qcustomplot.
    void setScatterProperty(const QString& scatter_name);

    //! Set up line for qcustomplot.
    void setLineProperty(const QString& line_name);

    //! Returns the name of the color, which follows the color of passes property
    //! container. If the container is nullptr or has the last-in-queue color,
    //! Returns default color.
    static const QString& nextColorName(Data1DProperties* properties);
};

#endif // BORNAGAIN_GUI_MODEL_DATA_DATAPROPERTIES_H
