//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/MultiLayerItems.cpp
//! @brief     Implements class MultiLayerItems
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Sample/MultiLayerItems.h"
#include "GUI/Model/Sample/ItemWithMaterial.h"
#include "GUI/Model/Sample/MultiLayerItem.h"
#include "GUI/Support/XML/Serialize.h"
#include <QApplication>

MultiLayerItems::~MultiLayerItems()
{
    qDeleteAll(m_multiLayers);
}

QVector<MultiLayerItem*> MultiLayerItems::multiLayerItems() const
{
    return m_multiLayers;
}

MultiLayerItem* MultiLayerItems::addMultiLayer()
{
    m_multiLayers << new MultiLayerItem();
    return m_multiLayers.back();
}

void MultiLayerItems::addMultiLayer(MultiLayerItem* multilayer)
{
    m_multiLayers << multilayer;
}

void MultiLayerItems::removeMultiLayer(MultiLayerItem* multilayer)
{
    m_multiLayers.removeAll(multilayer);
    delete multilayer;
}

QStringList MultiLayerItems::multiLayerNames() const
{
    QStringList existingNames;
    for (const auto* item : m_multiLayers)
        existingNames << item->sampleName();
    return existingNames;
}

void MultiLayerItems::serialize(Streamer& s)
{
    s.assertVersion(0);
    Serialize::rwVector(s, "Multilayers", m_multiLayers);
}
