//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Util/CoordName.cpp
//! @brief     Implements namespace GUI::Util::CoordName
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Util/CoordName.h"
#include <map>

namespace {

const std::map<QString, Axes::Coords> units_from_names{{"nbins", Axes::Coords::NBINS},
                                                       {"Radians", Axes::Coords::RADIANS},
                                                       {"Degrees", Axes::Coords::DEGREES},
                                                       {"mm", Axes::Coords::MM},
                                                       {"q-space", Axes::Coords::QSPACE}};

const std::map<Axes::Coords, QString> names_from_coords{{Axes::Coords::NBINS, "nbins"},
                                                        {Axes::Coords::RADIANS, "Radians"},
                                                        {Axes::Coords::MM, "mm"},
                                                        {Axes::Coords::QSPACE, "q-space"},
                                                        {Axes::Coords::DEGREES, "Degrees"}};

} // namespace

//! Correspondence of domain detector axes types to their GUI counterpart.

QString GUI::Util::CoordName::nameFromCoord(Axes::Coords units)
{
    const auto it = names_from_coords.find(units);
    if (it == names_from_coords.end())
        return "";
    return it->second;
}

//! Correspondence of GUI axes units names to their domain counterpart.

Axes::Coords GUI::Util::CoordName::coordFromName(const QString& name)
{
    return units_from_names.at(name);
}
