//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Instrument/OffSpecularInstrumentEditor.cpp
//! @brief     Implements class OffSpecularInstrumentEditor
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Instrument/OffSpecularInstrumentEditor.h"
#include "GUI/Model/Device/InstrumentItems.h"
#include "GUI/View/Instrument/DetectorEditor.h"
#include "GUI/View/Instrument/OffSpecularBeamEditor.h"
#include "GUI/View/Instrument/PolarizationAnalysisEditor.h"

#include <QVBoxLayout>

OffSpecularInstrumentEditor::OffSpecularInstrumentEditor(QWidget* parent,
                                                         OffSpecularInstrumentItem* instrument)
    : QWidget(parent)
{
    ASSERT(instrument)
    auto* layout = new QVBoxLayout(this);
    layout->setContentsMargins(0, 0, 0, 0);

    auto* beamEditor = new OffSpecularBeamEditor(this, instrument);
    layout->addWidget(beamEditor);

    auto* detectorEditor = new DetectorEditor(this, instrument);
    layout->addWidget(detectorEditor);

    auto* polpairAnalysisEditor = new PolarizationAnalysisEditor(this, instrument);
    layout->addWidget(polpairAnalysisEditor);

    layout->addStretch();

    connect(beamEditor, &OffSpecularBeamEditor::dataChanged, this,
            &OffSpecularInstrumentEditor::dataChanged);
    connect(detectorEditor, &DetectorEditor::dataChanged, this,
            &OffSpecularInstrumentEditor::dataChanged);
    connect(polpairAnalysisEditor, &PolarizationAnalysisEditor::dataChanged, this,
            &OffSpecularInstrumentEditor::dataChanged);
}
