//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/FullSpheroid.h
//! @brief     Defines class FullSpheroid.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_FULLSPHEROID_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_FULLSPHEROID_H

#include "Sample/Particle/IFormFactor.h"

//! A full spheroid (an ellipsoid with two equal axes, hence with circular cross section)
//! @ingroup hardParticle

class FullSpheroid : public IFormFactor {
public:
    FullSpheroid(double radius, double height);
#ifndef USER_API
    FullSpheroid(std::vector<double> P);

    FullSpheroid* clone() const override { return new FullSpheroid(m_radius, m_height); }
    std::string className() const final { return "FullSpheroid"; }
    // const auto tooltip = "ellipsoid of revolution";
    std::vector<ParaMeta> parDefs() const final
    {
        return {
            {"Radius", "nm", "revolution radius", 0, +INF, 0},
            {"Height", "nm", "height = twice the radius in non-revolution direction", 0, +INF, 0}};
    }

    double height() const { return m_height; }
    double radius() const { return m_radius; }

    double radialExtension() const override { return m_radius; }

    complex_t formfactor_at_bottom(C3 q) const override;

private:
    const double& m_radius;
    const double& m_height;
#endif // USER_API
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_FULLSPHEROID_H
