//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/HorizontalCylinder.h
//! @brief     Defines class Cylinder.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_HORIZONTALCYLINDER_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_HORIZONTALCYLINDER_H

#include "Sample/Particle/IFormFactor.h"

//! A circular cylinder.
//! @ingroup hardParticle

class HorizontalCylinder : public IFormFactor {
public:
    HorizontalCylinder(double radius, double length, double slice_bottom, double slice_top);
    HorizontalCylinder(double radius, double length);
#ifndef USER_API
    HorizontalCylinder(std::vector<double> P);

    HorizontalCylinder* clone() const override
    {
        return new HorizontalCylinder(m_radius, m_length, m_slice_bottom, m_slice_top);
    }
    std::string className() const final { return "HorizontalCylinder"; }
    // const auto tooltip = "circular cylinder";
    std::vector<ParaMeta> parDefs() const final
    {
        return {
            {"Radius", "nm", "radius of base", 0, +INF, 0},
            {"Length", "nm", "length", 0, +INF, 0},
            {"Slice_bottom", "nm", "Cut starts here (-R<=slice_bottom<slice_top<=+R)", -INF, +INF,
             0},
            {"Slice_top", "nm", "Cut ends here (-R<=slice_bottom<slice_top<=+R)", -INF, +INF, 0}};
    }

    double length() const { return m_length; }
    double radius() const { return m_radius; }
    double slice_bottom() const { return m_slice_bottom; }
    double slice_top() const { return m_slice_top; }

    double radialExtension() const override { return m_radius; }

    complex_t formfactor_at_bottom(C3 q) const override;

private:
    const double& m_radius;
    const double& m_length;
    const double& m_slice_bottom;
    const double& m_slice_top;
#endif // USER_API
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_HORIZONTALCYLINDER_H
