#include "Device/InputOutput/ReadWriteINT.h"
#include "Device/InputOutput/ReadWriteNumpyTXT.h"
#include "Device/InputOutput/ReadWriteTiff.h"
#include "Tests/GTestWrapper/google_test.h"

class IOReaderWriterTest : public ::testing::Test {
protected:
    IOReaderWriterTest();

    Powerfield<double> m_model_data;
};

IOReaderWriterTest::IOReaderWriterTest()
{
    FixedBinAxis axis1("x", 5, 1.0, 5.0);
    FixedBinAxis axis2("y", 10, 6.0, 7.0);
    m_model_data.addAxis(axis1);
    m_model_data.addAxis(axis2);
    for (size_t i = 0, size = m_model_data.getAllocatedSize(); i < size; ++i)
        m_model_data[i] = static_cast<double>(i);
}

TEST_F(IOReaderWriterTest, TestRWINT)
{
    std::stringstream ss;
    ReadWriteINT write_int;
    write_int.writePowerfield(m_model_data, ss);
    ReadWriteINT read_int;
    auto result = std::unique_ptr<Powerfield<double>>(read_int.readPowerfield(ss));

    auto compare_axis = [this, &result](size_t index) {
        EXPECT_EQ(m_model_data.axis(index).size(), result->axis(index).size());
        EXPECT_EQ(m_model_data.axis(index).lowerBound(), result->axis(index).lowerBound());
        EXPECT_EQ(m_model_data.axis(index).upperBound(), result->axis(index).upperBound());
    };

    EXPECT_EQ(m_model_data.rank(), result->rank());
    EXPECT_EQ(m_model_data.getAllSizes(), result->getAllSizes());
    compare_axis(0);
    compare_axis(1);
    for (size_t i = 0, size = m_model_data.getAllocatedSize(); i < size; ++i)
        EXPECT_EQ(m_model_data[i], (*result)[i]);
}

TEST_F(IOReaderWriterTest, TestRWNumpyTXT)
{
    std::stringstream ss;
    ReadWriteNumpyTXT write_txt;
    write_txt.writePowerfield(m_model_data, ss);

    ReadWriteNumpyTXT read_txt;
    auto result = std::unique_ptr<Powerfield<double>>(read_txt.readPowerfield(ss));
    EXPECT_EQ(m_model_data.rank(), result->rank());
    EXPECT_EQ(m_model_data.getAllSizes(), result->getAllSizes());
    for (size_t i = 0, size = m_model_data.getAllocatedSize(); i < size; ++i)
        EXPECT_EQ(m_model_data[i], (*result)[i]);
}

#ifdef BA_TIFF_SUPPORT

TEST_F(IOReaderWriterTest, TestRWTiff)
{
    std::stringstream ss;
    ReadWriteTiff write_tiff;
    write_tiff.writePowerfield(m_model_data, ss);

    ReadWriteTiff read_tiff;
    auto result = std::unique_ptr<Powerfield<double>>(read_tiff.readPowerfield(ss));
    EXPECT_EQ(m_model_data.rank(), result->rank());
    EXPECT_EQ(m_model_data.getAllSizes(), result->getAllSizes());
    for (size_t i = 0, size = m_model_data.getAllocatedSize(); i < size; ++i)
        EXPECT_EQ(m_model_data[i], (*result)[i]);
}

#endif // BA_TIFF_SUPPORT
