#include "GUI/Model/Descriptor/DoubleDescriptor.h"
#include "GUI/Model/Sample/LayerRoughnessItems.h"
#include "GUI/Model/To/ToDomain.h"
#include "GUI/View/FromDomain/FromDomain.h"
#include "Sample/Interface/LayerRoughness.h"
#include "Tests/GTestWrapper/google_test.h"

class TestLayerRoughnessItems : public ::testing::Test {
};

TEST_F(TestLayerRoughnessItems, LayerRoughnessToDomain)
{
    LayerBasicRoughnessItem roughnessItem;
    roughnessItem.sigma().set(10.0);
    roughnessItem.hurst().set(20.0);
    roughnessItem.lateralCorrelationLength().set(30.0);

    auto P_roughness = GUI::Transform::ToDomain::createLayerRoughness(&roughnessItem);
    EXPECT_EQ(P_roughness->sigma(), roughnessItem.sigma());
    EXPECT_EQ(P_roughness->hurst(), roughnessItem.hurst());
    EXPECT_EQ(P_roughness->lateralCorrLength(), roughnessItem.lateralCorrelationLength());

    // No roughness
    EXPECT_TRUE(GUI::Transform::ToDomain::createLayerRoughness(nullptr) == nullptr);
}

TEST_F(TestLayerRoughnessItems, LayerRoughnessFromDomain)
{
    LayerRoughness roughness(10.0, 20.0, 30.0);
    LayerBasicRoughnessItem roughnessItem;
    GUI::Transform::FromDomain::setRoughnessItem(&roughnessItem, roughness);
    EXPECT_EQ(roughness.sigma(), roughnessItem.sigma());
    EXPECT_EQ(roughness.hurst(), roughnessItem.hurst());
    EXPECT_EQ(roughness.lateralCorrLength(), roughnessItem.lateralCorrelationLength());
}
