#include "Resample/Flux/MatrixFlux.h"
#include "Tests/GTestWrapper/google_test.h"

class MatrixFluxTest : public ::testing::Test {
protected:
    MatrixFlux mrtcDefault{-1., {0., 0.}, R3{0.0, 0.0, 0.0}, 0.};
};

TEST_F(MatrixFluxTest, T1plus)
{
    Spinor s = mrtcDefault.T1plus();
    EXPECT_EQ(0.0, s.u);
    EXPECT_EQ(0.0, s.v);
}

TEST_F(MatrixFluxTest, T1min)
{
    Spinor s = mrtcDefault.T1min();
    EXPECT_EQ(0.0, s.u);
    EXPECT_EQ(complex_t(1.0, 0.0), s.v);
}

TEST_F(MatrixFluxTest, T2plus)
{
    Spinor s = mrtcDefault.T2plus();
    EXPECT_EQ(complex_t(1.0, 0.0), s.u);
    EXPECT_EQ(0.0, s.v);
}

TEST_F(MatrixFluxTest, T2min)
{
    Spinor s = mrtcDefault.T2min();
    EXPECT_EQ(0.0, s.u);
    EXPECT_EQ(0.0, s.v);
}

TEST_F(MatrixFluxTest, R1plus)
{
    Spinor s = mrtcDefault.R1plus();
    EXPECT_EQ(0.0, s.u);
    EXPECT_EQ(0.0, s.v);
}

TEST_F(MatrixFluxTest, R1min)
{
    Spinor s = mrtcDefault.R1min();
    EXPECT_EQ(0.0, s.u);
    EXPECT_EQ(complex_t(-1.0, 0.0), s.v);
}

TEST_F(MatrixFluxTest, R2plus)
{
    Spinor s = mrtcDefault.R2plus();
    EXPECT_EQ(complex_t(-1.0, 0.0), s.u);
    EXPECT_EQ(0.0, s.v);
}

TEST_F(MatrixFluxTest, R2min)
{
    Spinor s = mrtcDefault.R2min();
    EXPECT_EQ(0.0, s.u);
    EXPECT_EQ(0.0, s.v);
}

TEST_F(MatrixFluxTest, getKz)
{
    Spinor s = mrtcDefault.getKz();
    EXPECT_EQ(complex_t(0.0, 0.0), s.u);
    EXPECT_EQ(complex_t(0.0, 0.0), s.v);
}
