//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/SoftParticle/FuzzySphere.cpp
//! @brief     Implements class FuzzySphere.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Sample/SoftParticle/FuzzySphere.h"
#include "Sample/LibFF/SomeFormFactors.h"
#include "Sample/Shapes/TruncatedEllipsoidNet.h"

FuzzySphere::FuzzySphere(const std::vector<double> P)
    : IFormFactor(P)
    , m_radius(m_P[0])
    , m_sigma(m_P[1])
{
    checkNodeArgs();
    m_shape3D =
        std::make_unique<TruncatedEllipsoidNet>(m_radius, m_radius, m_radius, 2 * m_radius, 0);
}

FuzzySphere::FuzzySphere(double mean, double sigma)
    : FuzzySphere(std::vector<double>{mean, sigma})
{
}

complex_t FuzzySphere::formfactor_at_bottom(C3 q) const
{
    double q2 = std::norm(q.x()) + std::norm(q.y()) + std::norm(q.z());
    double dw = std::exp(-q2 * m_sigma * m_sigma / 2.0);
    return dw * SampleUtils::someff::ffSphere(q, m_radius);
}
